@@ -1,12 +1,15 @@
 """SCons.Debug
 
 Code for debugging SCons internal things.  Shouldn't be
-needed by most users.
+needed by most users. Quick shortcuts:
+
+from SCons.Debug import caller_trace
+caller_trace()
 
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -28,7 +31,7 @@ needed by most users.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Debug.py rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"
+__revision__ = "src/engine/SCons/Debug.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 import os
 import sys
@@ -94,7 +97,8 @@ def dumpLoggedInstances(classes, file=sys.stdout):
 if sys.platform[:5] == "linux":
     # Linux doesn't actually support memory usage stats from getrusage().
     def memory():
-        mstr = open('/proc/self/stat').read()
+        with open('/proc/self/stat') as f:
+            mstr = f.read()
         mstr = mstr.split()[22]
         return int(mstr)
 elif sys.platform[:6] == 'darwin':
@@ -137,8 +141,12 @@ def caller_stack():
 caller_bases = {}
 caller_dicts = {}
 
-# trace a caller's stack
 def caller_trace(back=0):
+    """
+    Trace caller stack and save info into global dicts, which
+    are printed automatically at the end of SCons execution.
+    """
+    global caller_bases, caller_dicts
     import traceback
     tb = traceback.extract_stack(limit=3+back)
     tb.reverse()
@@ -226,6 +234,7 @@ def Trace(msg, file=None, mode='w', tstamp=None):
         PreviousTime = now
     fp.write(msg)
     fp.flush()
+    fp.close()
 
 # Local Variables:
 # tab-width:4
