@@ -10,7 +10,7 @@ from distutils.msvccompiler.
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -33,7 +33,7 @@ from distutils.msvccompiler.
 #
 from __future__ import division
 
-__revision__ = "src/engine/SCons/Defaults.py rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"
+__revision__ = "src/engine/SCons/Defaults.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 
 import os
@@ -169,15 +169,73 @@ def get_paths_str(dest):
     else:
         return '"' + str(dest) + '"'
 
+permission_dic = {
+    'u':{
+        'r':stat.S_IRUSR,
+        'w':stat.S_IWUSR,
+        'x':stat.S_IXUSR
+    },
+    'g':{
+        'r':stat.S_IRGRP,
+        'w':stat.S_IWGRP,
+        'x':stat.S_IXGRP
+    },
+    'o':{
+        'r':stat.S_IROTH,
+        'w':stat.S_IWOTH,
+        'x':stat.S_IXOTH
+    }
+}
+
 def chmod_func(dest, mode):
+    import SCons.Util
+    from string import digits
     SCons.Node.FS.invalidate_node_memos(dest)
     if not SCons.Util.is_List(dest):
         dest = [dest]
-    for element in dest:
-        os.chmod(str(element), mode)
+    if SCons.Util.is_String(mode) and not 0 in [i in digits for i in mode]:
+        mode = int(mode, 8)
+    if not SCons.Util.is_String(mode):
+        for element in dest:
+            os.chmod(str(element), mode)
+    else:
+        mode = str(mode)
+        for operation in mode.split(","):
+            if "=" in operation:
+                operator = "="
+            elif "+" in operation:
+                operator = "+"
+            elif "-" in operation:
+                operator = "-"
+            else:
+                raise SyntaxError("Could not find +, - or =")
+            operation_list = operation.split(operator)
+            if len(operation_list) is not 2:
+                raise SyntaxError("More than one operator found")
+            user = operation_list[0].strip().replace("a", "ugo")
+            permission = operation_list[1].strip()
+            new_perm = 0
+            for u in user:
+                for p in permission:
+                    try:
+                        new_perm = new_perm | permission_dic[u][p]
+                    except KeyError:
+                        raise SyntaxError("Unrecognized user or permission format")
+            for element in dest:
+                curr_perm = os.stat(str(element)).st_mode
+                if operator == "=":
+                    os.chmod(str(element), new_perm)
+                elif operator == "+":
+                    os.chmod(str(element), curr_perm | new_perm)
+                elif operator == "-":
+                    os.chmod(str(element), curr_perm & ~new_perm)
 
 def chmod_strfunc(dest, mode):
-    return 'Chmod(%s, 0%o)' % (get_paths_str(dest), mode)
+    import SCons.Util
+    if not SCons.Util.is_String(mode):
+        return 'Chmod(%s, 0%o)' % (get_paths_str(dest), mode)
+    else:
+        return 'Chmod(%s, "%s")' % (get_paths_str(dest), str(mode))
 
 Chmod = ActionFactory(chmod_func, chmod_strfunc)
 
@@ -203,9 +261,13 @@ def copy_func(dest, src, symlinks=True):
         else:
             return copy_func(dest, os.path.realpath(src))
     elif os.path.isfile(src):
-        return shutil.copy2(src, dest)
+        shutil.copy2(src, dest)
+        return 0
     else:
-        return shutil.copytree(src, dest, symlinks)
+        shutil.copytree(src, dest, symlinks)
+        # copytree returns None in python2 and destination string in python3
+        # A error is raised in both cases, so we can just return 0 for success
+        return 0
 
 Copy = ActionFactory(
     copy_func,
@@ -240,7 +302,7 @@ def mkdir_func(dest):
     for entry in dest:
         try:
             os.makedirs(str(entry))
-        except os.error, e:
+        except os.error as e:
             p = str(entry)
             if (e.args[0] == errno.EEXIST or
                     (sys.platform=='win32' and e.args[0]==183)) \
@@ -280,6 +342,7 @@ Touch = ActionFactory(touch_func,
 
 # Internal utility functions
 
+
 def _concat(prefix, list, suffix, env, f=lambda x: x, target=None, source=None):
     """
     Creates a new list from 'list' by first interpolating each element
@@ -296,6 +359,7 @@ def _concat(prefix, list, suffix, env, f=lambda x: x, target=None, source=None):
 
     return _concat_ixes(prefix, list, suffix, env)
 
+
 def _concat_ixes(prefix, list, suffix, env):
     """
     Creates a new list from 'list' by concatenating the 'prefix' and
@@ -333,6 +397,7 @@ def _concat_ixes(prefix, list, suffix, env):
 
     return result
 
+
 def _stripixes(prefix, itms, suffix, stripprefixes, stripsuffixes, env, c=None):
     """
     This is a wrapper around _concat()/_concat_ixes() that checks for
@@ -400,7 +465,7 @@ def processDefines(defs):
                 else:
                     l.append(str(d[0]))
             elif SCons.Util.is_Dict(d):
-                for macro,value in d.iteritems():
+                for macro,value in d.items():
                     if value is not None:
                         l.append(str(macro) + '=' + str(value))
                     else:
@@ -426,6 +491,7 @@ def processDefines(defs):
         l = [str(defs)]
     return l
 
+
 def _defines(prefix, defs, suffix, env, c=_concat_ixes):
     """A wrapper around _concat_ixes that turns a list or string
     into a list of C preprocessor command-line definitions.
@@ -433,6 +499,7 @@ def _defines(prefix, defs, suffix, env, c=_concat_ixes):
 
     return c(prefix, env.subst_path(processDefines(defs)), suffix, env)
 
+
 class NullCmdGenerator(object):
     """This is a callable class that can be used in place of other
     command generators if you don't want them to do anything.
@@ -451,6 +518,7 @@ class NullCmdGenerator(object):
     def __call__(self, target, source, env, for_signature=None):
         return self.cmd
 
+
 class Variable_Method_Caller(object):
     """A class for finding a construction variable on the stack and
     calling one of its methods.
@@ -482,10 +550,10 @@ class Variable_Method_Caller(object):
             frame = frame.f_back
         return None
 
-# if env[version_var] id defined, returns env[flags_var], otherwise returns None
+# if $version_var is not empty, returns env[flags_var], otherwise returns None
 def __libversionflags(env, version_var, flags_var):
     try:
-        if env[version_var]:
+        if env.subst('$'+version_var):
             return env[flags_var]
     except KeyError:
         pass
@@ -493,14 +561,13 @@ def __libversionflags(env, version_var, flags_var):
 
 ConstructionEnvironment = {
     'BUILDERS'      : {},
-    'SCANNERS'      : [],
+    'SCANNERS'      : [ SCons.Tool.SourceFileScanner ],
     'CONFIGUREDIR'  : '#/.sconf_temp',
     'CONFIGURELOG'  : '#/config.log',
     'CPPSUFFIXES'   : SCons.Tool.CSuffixes,
     'DSUFFIXES'     : SCons.Tool.DSuffixes,
     'ENV'           : {},
     'IDLSUFFIXES'   : SCons.Tool.IDLSuffixes,
-#    'LATEXSUFFIXES' : SCons.Tool.LaTeXSuffixes, # moved to the TeX tools generate functions
     '_concat'       : _concat,
     '_defines'      : _defines,
     '_stripixes'    : _stripixes,
