@@ -7,7 +7,7 @@ stop, and wait on jobs.
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -29,7 +29,7 @@ stop, and wait on jobs.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Job.py rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"
+__revision__ = "src/engine/SCons/Job.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 import SCons.compat
 
@@ -70,7 +70,7 @@ class Jobs(object):
 
     def __init__(self, num, taskmaster):
         """
-        create 'num' jobs using the given taskmaster.
+        Create 'num' jobs using the given taskmaster.
 
         If 'num' is 1 or less, then a serial job will be used,
         otherwise a parallel job with 'num' worker threads will
@@ -126,10 +126,10 @@ class Jobs(object):
           c) SIGHUP: Controlling shell exiting
 
         We handle all of these cases by stopping the taskmaster. It
-        turns out that it very difficult to stop the build process
+        turns out that it's very difficult to stop the build process
         by throwing asynchronously an exception such as
         KeyboardInterrupt. For example, the python Condition
-        variables (threading.Condition) and queue's do not seem to
+        variables (threading.Condition) and queues do not seem to be
         asynchronous-exception-safe. It would require adding a whole
         bunch of try/finally block and except KeyboardInterrupt all
         over the place.
@@ -177,7 +177,7 @@ class Serial(object):
         The taskmaster's next_task() method should return the next task
         that needs to be executed, or None if there are no more tasks. The
         taskmaster's executed() method will be called for each task when it
-        is successfully executed or failed() will be called if it failed to
+        is successfully executed, or failed() will be called if it failed to
         execute (e.g. execute() raised an exception)."""
         
         self.taskmaster = taskmaster
@@ -278,14 +278,14 @@ else:
 
             try:
                 prev_size = threading.stack_size(stack_size*1024) 
-            except AttributeError, e:
+            except AttributeError as e:
                 # Only print a warning if the stack size has been
                 # explicitly set.
                 if not explicit_stack_size is None:
                     msg = "Setting stack size is unsupported by this version of Python:\n    " + \
                         e.args[0]
                     SCons.Warnings.warn(SCons.Warnings.StackSizeWarning, msg)
-            except ValueError, e:
+            except ValueError as e:
                 msg = "Setting stack size failed:\n    " + str(e)
                 SCons.Warnings.warn(SCons.Warnings.StackSizeWarning, msg)
 
@@ -351,7 +351,7 @@ else:
             The taskmaster's next_task() method should return the next
             task that needs to be executed, or None if there are no more
             tasks. The taskmaster's executed() method will be called
-            for each task when it is successfully executed or failed()
+            for each task when it is successfully executed, or failed()
             will be called if the task failed to execute (i.e. execute()
             raised an exception).
 
