@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -20,8 +20,9 @@
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
+from __future__ import print_function
 
-__revision__ = "src/engine/SCons/Memoize.py rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"
+__revision__ = "src/engine/SCons/Memoize.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 __doc__ = """Memoizer
 
@@ -33,7 +34,7 @@ values in a consistent way. In particular, it requires that the class uses a
 dictionary named "_memo" to store the cached values.
 
 Here is an example of wrapping a method that returns a computed value,
-with no input parameters:
+with no input parameters::
 
     @SCons.Memoize.CountMethodCall
     def foo(self):
@@ -50,7 +51,7 @@ with no input parameters:
         return result
 
 Here is an example of wrapping a method that will return different values
-based on one or more input arguments:
+based on one or more input arguments::
 
     def _bar_key(self, argument):                               # Memoization
         return argument                                         # Memoization
@@ -123,13 +124,12 @@ class Counter(object):
     def key(self):
         return self.cls_name+'.'+self.method_name
     def display(self):
-        fmt = "    %7d hits %7d misses    %s()"
-        print fmt % (self.hit, self.miss, self.key())
-    def __cmp__(self, other):
+        print("    {:7d} hits {:7d} misses    {}()".format(self.hit, self.miss, self.key()))
+    def __eq__(self, other):
         try:
-            return cmp(self.key(), other.key())
+            return self.key() == other.key()
         except AttributeError:
-            return 0
+            return True
 
 class CountValue(Counter):
     """
@@ -185,7 +185,7 @@ def Dump(title=None):
         collected so far.
     """
     if title:
-        print title
+        print(title)
     for counter in sorted(CounterList):
         CounterList[counter].display()
 
