@@ -12,7 +12,7 @@ it goes here.
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -34,13 +34,19 @@ it goes here.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Script/__init__.py rel_2.3.5:3347:d31d5a4e74b6 2015/07/31 14:36:10 bdbaddog"
+__revision__ = "src/engine/SCons/Script/__init__.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 import time
 start_time = time.time()
 
 import collections
 import os
+
+try:
+    from StringIO import StringIO
+except ImportError:
+    from io import StringIO
+
 import sys
 
 # Special chicken-and-egg handling of the "--debug=memoizer" flag:
@@ -66,7 +72,7 @@ if "--debug=memoizer" in _args:
     except SCons.Warnings.Warning:
         # Some warning was thrown.  Arrange for it to be displayed
         # or not after warnings are configured.
-        import Main
+        from . import Main
         exc_type, exc_value, tb = sys.exc_info()
         Main.delayed_warnings.append((exc_type, exc_value))
 del _args
@@ -75,8 +81,8 @@ import SCons.Action
 import SCons.Builder
 import SCons.Environment
 import SCons.Node.FS
-import SCons.Options
 import SCons.Platform
+import SCons.Platform.virtualenv
 import SCons.Scanner
 import SCons.SConf
 import SCons.Subst
@@ -85,7 +91,7 @@ import SCons.Util
 import SCons.Variables
 import SCons.Defaults
 
-import Main
+from . import Main
 
 main                    = Main.main
 
@@ -107,6 +113,7 @@ QuestionTask            = Main.QuestionTask
 #SConscriptSettableOptions = Main.SConscriptSettableOptions
 
 AddOption               = Main.AddOption
+PrintHelp               = Main.PrintHelp
 GetOption               = Main.GetOption
 SetOption               = Main.SetOption
 Progress                = Main.Progress
@@ -128,7 +135,7 @@ GetBuildFailures        = Main.GetBuildFailures
 #repositories            = Main.repositories
 
 #
-import SConscript
+from . import SConscript
 _SConscript = SConscript
 
 call_stack              = _SConscript.call_stack
@@ -143,6 +150,7 @@ Environment             = SCons.Environment.Environment
 #OptParser               = SCons.SConsOptions.OptParser
 FindPathDirs            = SCons.Scanner.FindPathDirs
 Platform                = SCons.Platform.Platform
+Virtualenv              = SCons.Platform.virtualenv.Virtualenv
 Return                  = _SConscript.Return
 Scanner                 = SCons.Scanner.Base
 Tool                    = SCons.Tool.Tool
@@ -155,12 +163,6 @@ ListVariable            = SCons.Variables.ListVariable
 PackageVariable         = SCons.Variables.PackageVariable
 PathVariable            = SCons.Variables.PathVariable
 
-# Deprecated names that will go away some day.
-BoolOption              = SCons.Options.BoolOption
-EnumOption              = SCons.Options.EnumOption
-ListOption              = SCons.Options.ListOption
-PackageOption           = SCons.Options.PackageOption
-PathOption              = SCons.Options.PathOption
 
 # Action factories.
 Chmod                   = SCons.Defaults.Chmod
@@ -258,23 +260,38 @@ def _Set_Default_Targets(env, tlist):
 #
 help_text = None
 
-def HelpFunction(text):
+def HelpFunction(text, append=False):
     global help_text
-    if SCons.Script.help_text is None:
-        SCons.Script.help_text = text
-    else:
-        help_text = help_text + text
+    if help_text is None:
+        if append:
+            s = StringIO()
+            PrintHelp(s)  
+            help_text = s.getvalue()
+            s.close()
+        else:
+            help_text = ""
+
+    help_text= help_text + text
+
 
 #
 # Will be non-zero if we are reading an SConscript file.
 sconscript_reading = 0
 
+_no_missing_sconscript = False
+_warn_missing_sconscript_deprecated = True
+
+def set_missing_sconscript_error(flag=1):
+    """Set behavior on missing file in SConscript() call. Returns previous value"""
+    global _no_missing_sconscript
+    old = _no_missing_sconscript
+    _no_missing_sconscript = flag
+    return old
+
 #
 def Variables(files=[], args=ARGUMENTS):
     return SCons.Variables.Variables(files, args)
 
-def Options(files=[], args=ARGUMENTS):
-    return SCons.Options.Options(files, args)
 
 # The list of global functions to add to the SConscript name space
 # that end up calling corresponding methods or Builders in the
@@ -318,10 +335,12 @@ GlobalDefaultEnvironmentFunctions = [
     'Ignore',
     'Install',
     'InstallAs',
+    'InstallVersionedLib',
     'Literal',
     'Local',
     'ParseDepends',
     'Precious',
+    'PyPackageDir',
     'Repository',
     'Requires',
     'SConsignFile',
@@ -344,6 +363,7 @@ GlobalDefaultBuilders = [
     'Java',
     'JavaH',
     'Library',
+    'LoadableModule',
     'M4',
     'MSVSProject',
     'Object',
@@ -357,14 +377,16 @@ GlobalDefaultBuilders = [
     'SharedObject',
     'StaticLibrary',
     'StaticObject',
+    'Substfile',
     'Tar',
+    'Textfile',
     'TypeLibrary',
     'Zip',
     'Package',
 ]
 
 for name in GlobalDefaultEnvironmentFunctions + GlobalDefaultBuilders:
-    exec "%s = _SConscript.DefaultEnvironmentCall(%s)" % (name, repr(name))
+    exec ("%s = _SConscript.DefaultEnvironmentCall(%s)" % (name, repr(name)))
 del name
 
 # There are a handful of variables that used to live in the
