@@ -9,7 +9,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2014 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -31,9 +31,9 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/gcc.py  2014/08/24 12:12:31 garyo"
+__revision__ = "src/engine/SCons/Tool/gcc.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
-import cc
+from . import cc
 import os
 import re
 import subprocess
@@ -42,6 +42,7 @@ import SCons.Util
 
 compilers = ['gcc', 'cc']
 
+
 def generate(env):
     """Add Builders and construction variables for gcc to an Environment."""
 
@@ -59,34 +60,36 @@ def generate(env):
     if version:
         env['CCVERSION'] = version
 
+
 def exists(env):
     # is executable, and is a GNU compiler (or accepts '--version' at least)
     return detect_version(env, env.Detect(env.get('CC', compilers)))
 
+
 def detect_version(env, cc):
     """Return the version of the GNU compiler, or None if it is not a GNU compiler."""
     cc = env.subst(cc)
     if not cc:
         return None
     version = None
-    #pipe = SCons.Action._subproc(env, SCons.Util.CLVar(cc) + ['-dumpversion'],
+    # pipe = SCons.Action._subproc(env, SCons.Util.CLVar(cc) + ['-dumpversion'],
     pipe = SCons.Action._subproc(env, SCons.Util.CLVar(cc) + ['--version'],
-                                 stdin = 'devnull',
-                                 stderr = 'devnull',
-                                 stdout = subprocess.PIPE)
+                                 stdin='devnull',
+                                 stderr='devnull',
+                                 stdout=subprocess.PIPE)
     # -dumpversion was added in GCC 3.0.  As long as we're supporting
     # GCC versions older than that, we should use --version and a
     # regular expression.
-    #line = pipe.stdout.read().strip()
-    #if line:
+    # line = pipe.stdout.read().strip()
+    # if line:
     #    version = line
-    line = pipe.stdout.readline()
+    line = SCons.Util.to_str(pipe.stdout.readline())
     match = re.search(r'[0-9]+(\.[0-9]+)+', line)
     if match:
         version = match.group(0)
     # Non-GNU compiler's output (like AIX xlc's) may exceed the stdout buffer:
     # So continue with reading to let the child process actually terminate.
-    while pipe.stdout.readline():
+    while SCons.Util.to_str(pipe.stdout.readline()):
         pass
     ret = pipe.wait()
     if ret != 0:
