@@ -10,7 +10,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -32,11 +32,11 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/gfortran.py rel_2.3.5:3347:d31d5a4e74b6 2015/07/31 14:36:10 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/gfortran.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 import SCons.Util
 
-import fortran
+from . import fortran
 
 def generate(env):
     """Add Builders and construction variables for gfortran to an
@@ -54,6 +54,8 @@ def generate(env):
         env['INC%sPREFIX' % dialect] = "-I"
         env['INC%sSUFFIX' % dialect] = ""
 
+    env['FORTRANMODDIRPREFIX'] = "-J"
+
 def exists(env):
     return env.Detect('gfortran')
 
