@@ -11,7 +11,7 @@ packages fake_root.
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -33,7 +33,7 @@ packages fake_root.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/ipkg.py rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/ipkg.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 import os
 
@@ -44,20 +44,26 @@ def generate(env):
     try:
         bld = env['BUILDERS']['Ipkg']
     except KeyError:
-        bld = SCons.Builder.Builder( action  = '$IPKGCOM',
-                                     suffix  = '$IPKGSUFFIX',
-                                     source_scanner = None,
-                                     target_scanner = None)
+        bld = SCons.Builder.Builder(action='$IPKGCOM',
+                                    suffix='$IPKGSUFFIX',
+                                    source_scanner=None,
+                                    target_scanner=None)
         env['BUILDERS']['Ipkg'] = bld
 
-    env['IPKG']       = 'ipkg-build'
-    env['IPKGCOM']    = '$IPKG $IPKGFLAGS ${SOURCE}'
-    env['IPKGUSER']   = os.popen('id -un').read().strip()
-    env['IPKGGROUP']  = os.popen('id -gn').read().strip()
-    env['IPKGFLAGS']  = SCons.Util.CLVar('-o $IPKGUSER -g $IPKGGROUP')
+
+    env['IPKG'] = 'ipkg-build'
+    env['IPKGCOM'] = '$IPKG $IPKGFLAGS ${SOURCE}'
+
+    if env.WhereIs('id'):
+        env['IPKGUSER'] = os.popen('id -un').read().strip()
+        env['IPKGGROUP'] = os.popen('id -gn').read().strip()
+    env['IPKGFLAGS'] = SCons.Util.CLVar('-o $IPKGUSER -g $IPKGGROUP')
     env['IPKGSUFFIX'] = '.ipk'
 
 def exists(env):
+    """
+    Can we find the tool
+    """
     return env.Detect('ipkg-build')
 
 # Local Variables:
