@@ -9,7 +9,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2017 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -31,12 +31,14 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/jar.py 74b2c53bc42290e911b334a6b44f187da698a668 2017/11/14 13:16:53 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/jar.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
+import os
 
 import SCons.Subst
 import SCons.Util
 from SCons.Node.FS import _my_normcase
-import os
+from SCons.Tool.JavaCommon import get_java_install_dirs
+
 
 def jarSources(target, source, env, for_signature):
     """Only include sources that are not a manifest file."""
@@ -52,7 +54,7 @@ def jarSources(target, source, env, for_signature):
     result = []
     for src in source:
         contents = src.get_text_contents()
-        if contents[:16] != "Manifest-Version":
+        if not contents.startswith("Manifest-Version"):
             if jarchdir_set:
                 _chdir = jarchdir
             else:
@@ -73,7 +75,7 @@ def jarManifest(target, source, env, for_signature):
     """Look in sources for a manifest file, if any."""
     for src in source:
         contents = src.get_text_contents()
-        if contents[:16] == "Manifest-Version":
+        if contents.startswith("Manifest-Version"):
             return src
     return ''
 
@@ -83,7 +85,7 @@ def jarFlags(target, source, env, for_signature):
     jarflags = env.subst('$JARFLAGS', target=target, source=source)
     for src in source:
         contents = src.get_text_contents()
-        if contents[:16] == "Manifest-Version":
+        if contents.startswith("Manifest-Version"):
             if not 'm' in jarflags:
                 return jarflags + 'm'
             break
@@ -115,7 +117,7 @@ def Jar(env, target = None, source = [], *args, **kw):
         return jars
 
     # they passed no target so make a target implicitly
-    if target == None:
+    if target is None:
         try:
             # make target from the first source file
             target = os.path.splitext(str(source[0]))[0] + env.subst('$JARSUFFIX')
@@ -133,68 +135,68 @@ def Jar(env, target = None, source = [], *args, **kw):
     # setup for checking through all the sources and handle accordingly
     java_class_suffix = env.subst('$JAVACLASSSUFFIX')
     java_suffix = env.subst('$JAVASUFFIX')
-    target_classes = []
+    target_nodes = []
 
     # function for determining what to do with a file and not a directory
     # if its already a class file then it can be used as a
     # source for jar, otherwise turn it into a class file then
     # return the source
     def file_to_class(s):
-        if(str(_my_normcase(s)).endswith(java_suffix)):
+        if _my_normcase(str(s)).endswith(java_suffix):
             return env.JavaClassFile(source = s, *args, **kw)
         else:
             return [env.fs.File(s)]
 
-    # In the case that we are passed just string to a node which is directory
-    # but does not exist, we need to check all the current targets to see if
-    # that directory is going to exist so we can add it as a source to Jar builder
-    def get_all_targets(env, node='.'):
-        def get_all_targets_iter(env, node):
-            if node.has_builder():
-                yield node
-            for kid in node.all_children():
-                for kid in get_all_targets(env, kid):
-                    yield kid
-        node = env.arg2nodes(node, env.fs.Entry)[0]
-        return list(get_all_targets_iter(env, node))
+    # function for calling the JavaClassDir builder if a directory is
+    # passed as a source to Jar builder. The JavaClassDir builder will
+    # return an empty list if there were not target classes built from
+    # the directory, in this case assume the user wanted the directory
+    # copied into the jar as is (it contains other files such as
+    # resources or class files compiled from proir commands)
+    # TODO: investigate the expexcted behavior for directories that
+    #       have mixed content, such as Java files along side other files
+    #       files.
+    def dir_to_class(s):
+        dir_targets = env.JavaClassDir(source = s, *args, **kw)
+        if(dir_targets == []):
+            # no classes files could be built from the source dir
+            # so pass the dir as is.
+            return [env.fs.Dir(s)]
+        else:
+            return dir_targets
 
     # loop through the sources and handle each accordingly
     # the goal here is to get all the source files into a class
     # file or a directory that contains class files
-    for s in source:
+    for s in SCons.Util.flatten(source):
         s = env.subst(s)
         if isinstance(s, SCons.Node.FS.Base):
             if isinstance(s, SCons.Node.FS.File):
                 # found a file so make sure its a class file
-                target_classes.extend(file_to_class(s))
+                target_nodes.extend(file_to_class(s))
             else:
-                # found a dir so make sure its a dir of class files
-                target_classes.extend(env.JavaClassDir(source = env.fs.Dir(s), *args, **kw))
+                # found a dir so get the class files out of it
+                target_nodes.extend(dir_to_class(s))
         else:
-            if os.path.isfile(s):
-                # found a file that exists on the FS, make sure its a class file
-                target_classes.extend(file_to_class(s))
-            elif os.path.isdir(s):
-                # found a dir on the FS, add it as a dir of class files
-                target_classes.append(env.fs.Dir(s))
-            elif s[-len(java_suffix):] == java_suffix or s[-len(java_class_suffix):] == java_class_suffix:
-                # found a file that may not exists and is only a string
-                # so add it after converting it to a class file
-                target_classes.extend(file_to_class(s))
-            else:
-                # found a swig file so add it after converting it to class files
-                if(os.path.splitext(str(s))[1] == ".i"):
-                    target_classes.extend(env.JavaClassFile(source = s, *args, **kw))
-                else:
-                    # found a directory that does not yet exist, but can exist as a node
-                    # check the target nodes to make sure it will be built, then add
-                    # it as a source
-                    for node in get_all_targets(env):
-                        if(s in str(node) and os.path.splitext(str(node))[1] == ""):
-                            target_classes.append(node)
+            try:
+                # source is string try to convert it to file
+                target_nodes.extend(file_to_class(env.fs.File(s)))
+                continue
+            except:
+                pass
+            
+            try:
+                # source is string try to covnert it to dir
+                target_nodes.extend(dir_to_class(env.fs.Dir(s)))
+                continue
+            except:
+                pass
+
+            SCons.Warnings.Warning("File: " + str(s) + " could not be identified as File or Directory, skipping.")
+            
     # at this point all our sources have been converted to classes or directories of class
     # so pass it to the Jar builder
-    return env.JarFile(target = target, source = target_classes, *args, **kw)
+    return env.JarFile(target = target, source = target_nodes, *args, **kw)
 
 def generate(env):
     """Add Builders and construction variables for jar to an Environment."""
@@ -206,6 +208,14 @@ def generate(env):
 
     env.AddMethod(Jar)
 
+    if env['PLATFORM'] == 'win32':
+        # Ensure that we have a proper path for clang
+        jar = SCons.Tool.find_program_path(env, 'jar',
+                                             default_paths=get_java_install_dirs(env['PLATFORM']))
+        if jar:
+            jar_bin_dir = os.path.dirname(jar)
+            env.AppendENVPath('PATH', jar_bin_dir)
+
     env['JAR']        = 'jar'
     env['JARFLAGS']   = SCons.Util.CLVar('cf')
     env['_JARFLAGS']  = jarFlags
