@@ -9,7 +9,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2017 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -31,7 +31,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/javah.py 74b2c53bc42290e911b334a6b44f187da698a668 2017/11/14 13:16:53 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/javah.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 import os.path
 
@@ -40,6 +40,8 @@ import SCons.Builder
 import SCons.Node.FS
 import SCons.Tool.javac
 import SCons.Util
+from SCons.Tool.JavaCommon import get_java_install_dirs
+
 
 def emit_java_headers(target, source, env):
     """Create and return lists of Java stub header files that will
@@ -120,6 +122,14 @@ def generate(env):
     java_javah = SCons.Tool.CreateJavaHBuilder(env)
     java_javah.emitter = emit_java_headers
 
+    if env['PLATFORM'] == 'win32':
+        # Ensure that we have a proper path for clang
+        javah = SCons.Tool.find_program_path(env, 'javah',
+                                             default_paths=get_java_install_dirs(env['PLATFORM']))
+        if javah:
+            javah_bin_dir = os.path.dirname(javah)
+            env.AppendENVPath('PATH', javah_bin_dir)
+
     env['_JAVAHOUTFLAG']    = JavaHOutFlagGenerator
     env['JAVAH']            = 'javah'
     env['JAVAHFLAGS']       = SCons.Util.CLVar('')
