@@ -9,7 +9,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -31,10 +31,11 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/mingw.py rel_2.3.5:3347:d31d5a4e74b6 2015/07/31 14:36:10 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/mingw.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 import os
 import os.path
+import glob
 
 import SCons.Action
 import SCons.Builder
@@ -42,26 +43,14 @@ import SCons.Defaults
 import SCons.Tool
 import SCons.Util
 
-# This is what we search for to find mingw:
-key_program = 'mingw32-gcc'
 
-def find(env):
-    # First search in the SCons path
-    path=env.WhereIs(key_program)
-    if (path):
-        return path
-    # then the OS path:
-    path=SCons.Util.WhereIs(key_program)
-    if (path):
-        return path
-
-    # If that doesn't work try default location for mingw
-    save_path=env['ENV']['PATH']
-    env.AppendENVPath('PATH',r'c:\MinGW\bin')
-    path =env.WhereIs(key_program)
-    if not path:
-        env['ENV']['PATH']=save_path
-    return path
+mingw_paths = [
+    r'c:\MinGW\bin',
+    r'C:\cygwin64\bin',
+    r'C:\msys64',
+    r'C:\cygwin\bin',
+    r'C:\msys',
+]
 
 def shlib_generator(target, source, env, for_signature):
     cmd = SCons.Util.CLVar(['$SHLINK', '$SHLINKFLAGS']) 
@@ -86,7 +75,8 @@ def shlib_emitter(target, source, env):
     no_import_lib = env.get('no_import_lib', 0)
 
     if not dll:
-        raise SCons.Errors.UserError("A shared library should have exactly one target with the suffix: %s" % env.subst("$SHLIBSUFFIX"))
+        raise SCons.Errors.UserError("A shared library should have exactly one target with the suffix: %s Target(s) are:%s" %  \
+            (env.subst("$SHLIBSUFFIX"), ",".join([str(t) for t in target])))
     
     if not no_import_lib and \
        not env.FindIxes(target, 'LIBPREFIX', 'LIBSUFFIX'):
@@ -125,12 +115,33 @@ res_builder = SCons.Builder.Builder(action=res_action, suffix='.o',
                                     source_scanner=SCons.Tool.SourceFileScanner)
 SCons.Tool.SourceFileScanner.add_scanner('.rc', SCons.Defaults.CScan)
 
+# This is what we search for to find mingw:
+# key_program = 'mingw32-gcc'
+key_program = 'mingw32-make'
+
+
+
+def find_version_specific_mingw_paths():
+    """
+    One example of default mingw install paths is:
+    C:\mingw-w64\x86_64-6.3.0-posix-seh-rt_v5-rev2\mingw64\bin
+
+    Use glob'ing to find such and add to mingw_paths
+    """
+    new_paths = glob.glob(r"C:\mingw-w64\*\mingw64\bin")
+    
+    return new_paths
+
+
 def generate(env):
-    mingw = find(env)
+    global mingw_paths
+    # Check for reasoanble mingw default paths
+    mingw_paths +=find_version_specific_mingw_paths() 
+
+    mingw = SCons.Tool.find_program_path(env, key_program, default_paths=mingw_paths)
     if mingw:
-        dir = os.path.dirname(mingw)
-        env.PrependENVPath('PATH', dir )
-        
+        mingw_bin_dir = os.path.dirname(mingw)
+        env.AppendENVPath('PATH', mingw_bin_dir)
 
     # Most of mingw is the same as gcc and friends...
     gnu_tools = ['gcc', 'g++', 'gnulink', 'ar', 'gas', 'gfortran', 'm4']
@@ -146,6 +157,7 @@ def generate(env):
     env['SHLINKCOM']   = shlib_action
     env['LDMODULECOM'] = shlib_action
     env.Append(SHLIBEMITTER = [shlib_emitter])
+    env.Append(LDMODULEEMITTER = [shlib_emitter])
     env['AS'] = 'as'
 
     env['WIN32DEFPREFIX']        = ''
@@ -171,7 +183,12 @@ def generate(env):
     env['PROGSUFFIX'] = '.exe'
 
 def exists(env):
-    return find(env)
+    mingw = SCons.Tool.find_program_path(env, key_program, default_paths=mingw_paths)
+    if mingw:
+        mingw_bin_dir = os.path.dirname(mingw)
+        env.AppendENVPath('PATH', mingw_bin_dir)
+
+    return mingw
 
 # Local Variables:
 # tab-width:4
