@@ -3,7 +3,7 @@
 Tool specific initialization for `msgmerge` tool.
 """
 
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 # 
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -24,7 +24,7 @@ Tool specific initialization for `msgmerge` tool.
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "src/engine/SCons/Tool/msgmerge.py rel_2.3.5:3347:d31d5a4e74b6 2015/07/31 14:36:10 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/msgmerge.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 #############################################################################
 def _update_or_init_po_files(target, source, env):
@@ -58,7 +58,7 @@ def _POUpdateBuilderWrapper(env, target=None, source=_null, **kw):
   if source is _null:
     if 'POTDOMAIN' in kw:
       domain = kw['POTDOMAIN']
-    elif env.has_key('POTDOMAIN') and env['POTDOMAIN']:
+    elif 'POTDOMAIN' in env and env['POTDOMAIN']:
       domain = env['POTDOMAIN']
     else:
       domain = 'messages'
@@ -68,8 +68,21 @@ def _POUpdateBuilderWrapper(env, target=None, source=_null, **kw):
 
 #############################################################################
 def generate(env,**kw):
-  """ Generate the `xgettext` tool """
+  """ Generate the `msgmerge` tool """
+  import sys
+  import os
+  import SCons.Tool
   from SCons.Tool.GettextCommon import _detect_msgmerge
+  from SCons.Platform.mingw import MINGW_DEFAULT_PATHS
+  from SCons.Platform.cygwin import CYGWIN_DEFAULT_PATHS
+
+  if sys.platform == 'win32':
+      msgmerge = SCons.Tool.find_program_path(env, 'msgmerge', default_paths=MINGW_DEFAULT_PATHS + CYGWIN_DEFAULT_PATHS )
+      if msgmerge:
+          msgmerge_bin_dir = os.path.dirname(msgmerge)
+          env.AppendENVPath('PATH', msgmerge_bin_dir)
+      else:
+          SCons.Warnings.Warning('msgmerge tool requested, but binary not found in ENV PATH')
   try:
     env['MSGMERGE'] = _detect_msgmerge(env)
   except:
