@@ -4,7 +4,7 @@ The msi packager.
 """
 
 #
-# Copyright (c) 2001 - 2014 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 # 
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -25,7 +25,7 @@ The msi packager.
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "src/engine/SCons/Tool/packaging/msi.py  2014/08/24 12:12:31 garyo"
+__revision__ = "src/engine/SCons/Tool/packaging/msi.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 import os
 import SCons
@@ -63,14 +63,14 @@ def convert_to_id(s, id_set):
     """
     charset = 'ABCDEFGHIJKLMNOPQRSTUVWXYabcdefghijklmnopqrstuvwxyz0123456789_.'
     if s[0] in '0123456789.':
-        s += '_'+s
-    id = [c for c in s if c in charset]
+        s = '_' + s
+    id = ''.join([c for c in s if c in charset])
 
     # did we already generate an id for this file?
     try:
         return id_set[id][s]
     except KeyError:
-        # no we did not so initialize with the id
+        # no we did not, so initialize with the id
         if id not in id_set: id_set[id] = { s : id }
         # there is a collision, generate an id which is unique by appending
         # the collision number
@@ -79,7 +79,7 @@ def convert_to_id(s, id_set):
         return id_set[id][s]
 
 def is_dos_short_file_name(file):
-    """ examine if the given file is in the 8.3 form.
+    """ Examine if the given file is in the 8.3 form.
     """
     fname, ext = os.path.splitext(file)
     proper_ext = len(ext) == 0 or (2 <= len(ext) <= 4) # the ext contains the dot
@@ -88,7 +88,7 @@ def is_dos_short_file_name(file):
     return proper_ext and proper_fname
 
 def gen_dos_short_file_name(file, filename_set):
-    """ see http://support.microsoft.com/default.aspx?scid=kb;en-us;Q142982
+    """ See http://support.microsoft.com/default.aspx?scid=kb;en-us;Q142982
 
     These are no complete 8.3 dos short names. The ~ char is missing and 
     replaced with one character from the filename. WiX warns about such
@@ -108,14 +108,13 @@ def gen_dos_short_file_name(file, filename_set):
 
     # strip forbidden characters.
     forbidden = '."/[]:;=, '
-    fname = [c for c in fname if c not in forbidden]
+    fname = ''.join([c for c in fname if c not in forbidden])
 
     # check if we already generated a filename with the same number:
     # thisis1.txt, thisis2.txt etc.
     duplicate, num = not None, 1
     while duplicate:
-        shortname = "%s%s" % (fname[:8-len(str(num))].upper(),\
-                              str(num))
+        shortname = "%s%s" % (fname[:8-len(str(num))].upper(), str(num))
         if len(ext) >= 2:
             shortname = "%s%s" % (shortname, ext[:4].upper())
 
@@ -186,10 +185,10 @@ def string_wxsfile(target, source, env):
     return "building WiX file %s"%( target[0].path )
 
 def build_wxsfile(target, source, env):
-    """ compiles a .wxs file from the keywords given in env['msi_spec'] and
+    """ Compiles a .wxs file from the keywords given in env['msi_spec'] and
         by analyzing the tree of source nodes and their tags.
     """
-    file = open(target[0].abspath, 'w')
+    file = open(target[0].get_abspath(), 'w')
 
     try:
         # Create a document with the Wix root tag
@@ -216,7 +215,7 @@ def build_wxsfile(target, source, env):
         if 'CHANGE_SPECFILE' in env:
             env['CHANGE_SPECFILE'](target, source)
 
-    except KeyError, e:
+    except KeyError as e:
         raise SCons.Errors.UserError( '"%s" package field for MSI is missing.' % e.args[0] )
 
 #
@@ -268,7 +267,7 @@ def create_default_directory_layout(root, NAME, VERSION, VENDOR, filename_set):
 # mandatory and optional file tags
 #
 def build_wxsfile_file_section(root, files, NAME, VERSION, VENDOR, filename_set, id_set):
-    """ builds the Component sections of the wxs file with their included files.
+    """ Builds the Component sections of the wxs file with their included files.
 
     Files need to be specified in 8.3 format and in the long name format, long
     filenames will be converted automatically.
@@ -280,7 +279,7 @@ def build_wxsfile_file_section(root, files, NAME, VERSION, VENDOR, filename_set,
     factory    = Document()
 
     def get_directory( node, dir ):
-        """ returns the node under the given node representing the directory.
+        """ Returns the node under the given node representing the directory.
 
         Returns the component node if dir is None or empty.
         """
@@ -301,7 +300,7 @@ def build_wxsfile_file_section(root, files, NAME, VERSION, VENDOR, filename_set,
                                if c.nodeName == 'Directory'
                                and c.attributes['LongName'].value == escape(d)] 
 
-            if already_created != []:
+            if already_created:
                 Directory = already_created[0]
                 dir_parts.remove(d)
                 upper_dir += d
@@ -415,7 +414,7 @@ def build_wxsfile_features_section(root, files, NAME, VERSION, SUMMARY, id_set):
     root.getElementsByTagName('Product')[0].childNodes.append(Feature)
 
 def build_wxsfile_default_gui(root):
-    """ this function adds a default GUI to the wxs file
+    """ This function adds a default GUI to the wxs file
     """
     factory = Document()
     Product = root.getElementsByTagName('Product')[0]
@@ -429,7 +428,7 @@ def build_wxsfile_default_gui(root):
     Product.childNodes.append(UIRef)
 
 def build_license_file(directory, spec):
-    """ creates a License.rtf file with the content of "X_MSI_LICENSE_TEXT"
+    """ Creates a License.rtf file with the content of "X_MSI_LICENSE_TEXT"
     in the given directory
     """
     name, text = '', ''
