@@ -4,7 +4,7 @@ The rpm packager.
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -25,7 +25,7 @@ The rpm packager.
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "src/engine/SCons/Tool/packaging/rpm.py rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/packaging/rpm.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 import os
 
@@ -51,10 +51,9 @@ def package(env, target, source, PACKAGEROOT, NAME, VERSION,
     if str(target[0])!="%s-%s"%(NAME, VERSION):
         raise UserError( "Setting target is not supported for rpm." )
     else:
-        # This should be overridable from the construction environment,
-        # which it is by using ARCHITECTURE=.
+        # Deduce the build architecture, but allow it to be overridden
+        # by setting ARCHITECTURE in the construction env.
         buildarchitecture = SCons.Tool.rpmutils.defaultMachine()
-
         if 'ARCHITECTURE' in kw:
             buildarchitecture = kw['ARCHITECTURE']
 
@@ -72,7 +71,6 @@ def package(env, target, source, PACKAGEROOT, NAME, VERSION,
 
     # if no "SOURCE_URL" tag is given add a default one.
     if 'SOURCE_URL' not in kw:
-        #kw['SOURCE_URL']=(str(target[0])+".tar.gz").replace('.rpm', '')
         kw['SOURCE_URL']=(str(target[0])+".tar.gz").replace('.rpm', '')
 
     # mangle the source and target list for the rpmbuild
@@ -86,28 +84,25 @@ def package(env, target, source, PACKAGEROOT, NAME, VERSION,
 
 def collectintargz(target, source, env):
     """ Puts all source files into a tar.gz file. """
-    # the rpm tool depends on a source package, until this is chagned
+    # the rpm tool depends on a source package, until this is changed
     # this hack needs to be here that tries to pack all sources in.
     sources = env.FindSourceFiles()
 
     # filter out the target we are building the source list for.
-    #sources = [s for s in sources if not (s in target)]
     sources = [s for s in sources if s not in target]
 
     # find the .spec file for rpm and add it since it is not necessarily found
     # by the FindSourceFiles function.
-    #sources.extend( [s for s in source if str(s).rfind('.spec')!=-1] )
-    spec_file = lambda s: str(s).rfind('.spec') != -1
-    sources.extend( list(filter(spec_file, source)) )
+    sources.extend( [s for s in source if str(s).rfind('.spec')!=-1] )
+    # sort to keep sources from changing order across builds
+    sources.sort()
 
     # as the source contains the url of the source package this rpm package
     # is built from, we extract the target name
-    #tarball = (str(target[0])+".tar.gz").replace('.rpm', '')
     tarball = (str(target[0])+".tar.gz").replace('.rpm', '')
     try:
-        #tarball = env['SOURCE_URL'].split('/')[-1]
         tarball = env['SOURCE_URL'].split('/')[-1]
-    except KeyError, e:
+    except KeyError as e:
         raise SCons.Errors.UserError( "Missing PackageTag '%s' for RPM packager" % e.args[0] )
 
     tarball = src_targz.package(env, source=sources, target=tarball,
@@ -130,20 +125,18 @@ def build_specfile(target, source, env):
     """ Builds a RPM specfile from a dictionary with string metadata and
     by analyzing a tree of nodes.
     """
-    file = open(target[0].get_abspath(), 'w')
+    with open(target[0].get_abspath(), 'w') as file:
+        try:
+            file.write(build_specfile_header(env))
+            file.write(build_specfile_sections(env))
+            file.write(build_specfile_filesection(env, source))
 
-    try:
-        file.write( build_specfile_header(env) )
-        file.write( build_specfile_sections(env) )
-        file.write( build_specfile_filesection(env, source) )
-        file.close()
+            # call a user specified function
+            if 'CHANGE_SPECFILE' in env:
+                env['CHANGE_SPECFILE'](target, source)
 
-        # call a user specified function
-        if 'CHANGE_SPECFILE' in env:
-            env['CHANGE_SPECFILE'](target, source)
-
-    except KeyError, e:
-        raise SCons.Errors.UserError( '"%s" package field for RPM is missing.' % e.args[0] )
+        except KeyError as e:
+            raise SCons.Errors.UserError('"%s" package field for RPM is missing.' % e.args[0])
 
 
 #
@@ -194,7 +187,7 @@ def build_specfile_sections(spec):
     return str
 
 def build_specfile_header(spec):
-    """ Builds all section but the %file of a rpm specfile
+    """ Builds all sections but the %file of a rpm specfile
     """
     str = ""
 
@@ -205,7 +198,8 @@ def build_specfile_header(spec):
         'PACKAGEVERSION' : '%%define release %s\nRelease: %%{release}\n',
         'X_RPM_GROUP'    : 'Group: %s\n',
         'SUMMARY'        : 'Summary: %s\n',
-        'LICENSE'        : 'License: %s\n', }
+        'LICENSE'        : 'License: %s\n',
+    }
 
     str = str + SimpleTagCompiler(mandatory_header_fields).compile( spec )
 
@@ -215,6 +209,7 @@ def build_specfile_header(spec):
         'X_RPM_URL'           : 'Url: %s\n',
         'SOURCE_URL'          : 'Source: %s\n',
         'SUMMARY_'            : 'Summary(%s): %s\n',
+        'ARCHITECTURE'        : 'BuildArch: %s\n',
         'X_RPM_DISTRIBUTION'  : 'Distribution: %s\n',
         'X_RPM_ICON'          : 'Icon: %s\n',
         'X_RPM_PACKAGER'      : 'Packager: %s\n',
@@ -231,22 +226,35 @@ def build_specfile_header(spec):
         'X_RPM_EXCLUDEARCH'   : 'ExcludeArch: %s\n',
         'X_RPM_EXCLUSIVEARCH' : 'ExclusiveArch: %s\n',
         'X_RPM_PREFIX'        : 'Prefix: %s\n',
-        'X_RPM_CONFLICTS'     : 'Conflicts: %s\n',
 
         # internal use
-        'X_RPM_BUILDROOT'     : 'BuildRoot: %s\n', }
+        'X_RPM_BUILDROOT'     : 'BuildRoot: %s\n',
+    }
 
     # fill in default values:
-    # Adding a BuildRequires renders the .rpm unbuildable under System, which
+    # Adding a BuildRequires renders the .rpm unbuildable under systems which
     # are not managed by rpm, since the database to resolve this dependency is
     # missing (take Gentoo as an example)
-#    if not s.has_key('x_rpm_BuildRequires'):
-#        s['x_rpm_BuildRequires'] = 'scons'
+    #if 'X_RPM_BUILDREQUIRES' not in spec:
+    #    spec['X_RPM_BUILDREQUIRES'] = 'scons'
 
     if 'X_RPM_BUILDROOT' not in spec:
         spec['X_RPM_BUILDROOT'] = '%{_tmppath}/%{name}-%{version}-%{release}'
 
     str = str + SimpleTagCompiler(optional_header_fields, mandatory=0).compile( spec )
+
+    # Add any extra specfile definitions the user may have supplied.
+    # These flags get no processing, they are just added.
+    # github #3164: if we don't turn off debug package generation
+    # the tests which build packages all fail.  If there are no
+    # extra flags, default to adding this one. If the user wants
+    # to turn this back on, supply the flag set to None.
+
+    if 'X_RPM_EXTRADEFS' not in spec:
+        spec['X_RPM_EXTRADEFS'] = ['%global debug_package %{nil}']
+    for extra in spec['X_RPM_EXTRADEFS']:
+        str += extra + '\n'
+
     return str
 
 #
@@ -276,7 +284,7 @@ def build_specfile_filesection(spec, files):
     for file in files:
         # build the tagset
         tags = {}
-        for k in supported_tags.keys():
+        for k in list(supported_tags.keys()):
             try:
                 v = file.GetTag(k)
                 if v:
@@ -312,11 +320,10 @@ class SimpleTagCompiler(object):
         self.mandatory = mandatory
 
     def compile(self, values):
-        """ compiles the tagset and returns a str containing the result
+        """ Compiles the tagset and returns a str containing the result
         """
         def is_international(tag):
-            #return tag.endswith('_')
-            return tag[-1:] == '_'
+            return tag.endswith('_')
 
         def get_country_code(tag):
             return tag[-2:]
@@ -327,25 +334,22 @@ class SimpleTagCompiler(object):
         replacements = list(self.tagset.items())
 
         str = ""
-        #domestic = [ (k,v) for k,v in replacements if not is_international(k) ]
         domestic = [t for t in replacements if not is_international(t[0])]
         for key, replacement in domestic:
             try:
                 str = str + replacement % values[key]
-            except KeyError, e:
+            except KeyError as e:
                 if self.mandatory:
                     raise e
 
-        #international = [ (k,v) for k,v in replacements if is_international(k) ]
         international = [t for t in replacements if is_international(t[0])]
         for key, replacement in international:
             try:
-                #int_values_for_key = [ (get_country_code(k),v) for k,v in values.items() if strip_country_code(k) == key ]
                 x = [t for t in values.items() if strip_country_code(t[0]) == key]
                 int_values_for_key = [(get_country_code(t[0]),t[1]) for t in x]
                 for v in int_values_for_key:
                     str = str + replacement % v
-            except KeyError, e:
+            except KeyError as e:
                 if self.mandatory:
                     raise e
 
