@@ -9,7 +9,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2014 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -31,7 +31,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/rmic.py  2014/08/24 12:12:31 garyo"
+__revision__ = "src/engine/SCons/Tool/rmic.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 import os.path
 
@@ -40,6 +40,9 @@ import SCons.Builder
 import SCons.Node.FS
 import SCons.Util
 
+from SCons.Tool.JavaCommon import get_java_install_dirs
+
+
 def emit_rmic_classes(target, source, env):
     """Create and return lists of Java RMI stub and skeleton
     class files to be created from a set of class files.
@@ -105,6 +108,18 @@ def generate(env):
     """Add Builders and construction variables for rmic to an Environment."""
     env['BUILDERS']['RMIC'] = RMICBuilder
 
+    if env['PLATFORM'] == 'win32':
+        version = env.get('JAVAVERSION', None)
+        default_paths=get_java_install_dirs(env['PLATFORM'], version=version)
+
+        # Ensure that we have a proper path for rmic
+        rmic = SCons.Tool.find_program_path(env, 'rmic', default_paths=default_paths)
+
+        # print("RMIC: %s"%rmic)
+        if rmic:
+            rmic_bin_dir = os.path.dirname(rmic)
+            env.AppendENVPath('PATH', rmic_bin_dir)
+
     env['RMIC']            = 'rmic'
     env['RMICFLAGS']       = SCons.Util.CLVar('')
     env['RMICCOM']         = '$RMIC $RMICFLAGS -d ${TARGET.attributes.java_lookupdir} -classpath ${SOURCE.attributes.java_classdir} ${SOURCES.attributes.java_classname}'
