@@ -9,7 +9,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -31,13 +31,16 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/yacc.py rel_2.3.5:3347:d31d5a4e74b6 2015/07/31 14:36:10 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/yacc.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 import os.path
+import sys
 
 import SCons.Defaults
 import SCons.Tool
 import SCons.Util
+from SCons.Platform.mingw import MINGW_DEFAULT_PATHS
+from SCons.Platform.cygwin import CYGWIN_DEFAULT_PATHS
 
 YaccAction = SCons.Action.Action("$YACCCOM", "$YACCCOMSTR")
 
@@ -61,7 +64,7 @@ def _yaccEmitter(target, source, env, ysuf, hsuf):
         base, ext = os.path.splitext(SCons.Util.to_String(source[0]))
         target.append(base + env.subst("$YACCVCGFILESUFFIX"))
 
-    # If -v is specirfied yacc will create the output debug file
+    # If -v is specified yacc will create the output debug file
     # which is not really source for any process, but should
     # be noted and also be cleaned
     # Bug #2558
@@ -113,19 +116,19 @@ def generate(env):
     cxx_file.add_action('.yy', YaccAction)
     cxx_file.add_emitter('.yy', yyEmitter)
 
+    if sys.platform == 'win32':
+        bison = SCons.Tool.find_program_path(env, 'bison', default_paths=MINGW_DEFAULT_PATHS + CYGWIN_DEFAULT_PATHS )
+        if bison:
+            bison_bin_dir = os.path.dirname(bison)
+            env.AppendENVPath('PATH', bison_bin_dir)
+        else:
+            SCons.Warnings.Warning('yacc tool requested, but bison binary not found in ENV PATH')
+
     env['YACC']      = env.Detect('bison') or 'yacc'
     env['YACCFLAGS'] = SCons.Util.CLVar('')
     env['YACCCOM']   = '$YACC $YACCFLAGS -o $TARGET $SOURCES'
     env['YACCHFILESUFFIX'] = '.h'
 
-    # Apparently, OS X now creates file.hpp like everybody else
-    # I have no idea when it changed; it was fixed in 10.4
-    #if env['PLATFORM'] == 'darwin':
-    #    # Bison on Mac OS X just appends ".h" to the generated target .cc
-    #    # or .cpp file name.  Hooray for delayed expansion of variables.
-    #    env['YACCHXXFILESUFFIX'] = '${TARGET.suffix}.h'
-    #else:
-    #    env['YACCHXXFILESUFFIX'] = '.hpp'
     env['YACCHXXFILESUFFIX'] = '.hpp'
 
     env['YACCVCGFILESUFFIX'] = '.vcg'
