@@ -9,7 +9,7 @@ selection method.
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -31,7 +31,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/zip.py rel_2.4.0:3365:9259ea1c13d7 2015/09/21 14:03:43 bdbaddog"
+__revision__ = "src/engine/SCons/Tool/zip.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 import os.path
 
@@ -40,31 +40,23 @@ import SCons.Defaults
 import SCons.Node.FS
 import SCons.Util
 
-try:
-    import zipfile
-    internal_zip = 1
-except ImportError:
-    internal_zip = 0
+import zipfile
 
-if internal_zip:
-    zipcompression = zipfile.ZIP_DEFLATED
-    def zip(target, source, env):
-        compression = env.get('ZIPCOMPRESSION', 0)
-        zf = zipfile.ZipFile(str(target[0]), 'w', compression)
-        for s in source:
-            if s.isdir():
-                for dirpath, dirnames, filenames in os.walk(str(s)):
-                    for fname in filenames:
-                        path = os.path.join(dirpath, fname)
-                        if os.path.isfile(path):
-                            zf.write(path, os.path.relpath(path, str(env.get('ZIPROOT', ''))))
-            else:
-                zf.write(str(s), os.path.relpath(str(s), str(env.get('ZIPROOT', ''))))
-        zf.close()
-else:
-    zipcompression = 0
-    zip = "$ZIP $ZIPFLAGS ${TARGET.abspath} $SOURCES"
+zipcompression = zipfile.ZIP_DEFLATED
+def zip(target, source, env):
+    compression = env.get('ZIPCOMPRESSION', 0)
+    zf = zipfile.ZipFile(str(target[0]), 'w', compression)
+    for s in source:
+        if s.isdir():
+            for dirpath, dirnames, filenames in os.walk(str(s)):
+                for fname in filenames:
+                    path = os.path.join(dirpath, fname)
+                    if os.path.isfile(path):
 
+                        zf.write(path, os.path.relpath(path, str(env.get('ZIPROOT', ''))))
+        else:
+            zf.write(str(s), os.path.relpath(str(s), str(env.get('ZIPROOT', ''))))
+    zf.close()
 
 zipAction = SCons.Action.Action(zip, varlist=['ZIPCOMPRESSION'])
 
@@ -91,7 +83,7 @@ def generate(env):
     env['ZIPROOT']    = SCons.Util.CLVar('')
 
 def exists(env):
-    return internal_zip or env.Detect('zip')
+    return True
 
 # Local Variables:
 # tab-width:4
