@@ -11,24 +11,24 @@ Usage example:
   Examples:
       x11=no   (disables X11 support)
       x11=yes  (will search for the package installation dir)
-      x11=/usr/local/X11 (will check this path for existance)
+      x11=/usr/local/X11 (will check this path for existence)
 
-  To replace autoconf's --with-xxx=yyy 
+  To replace autoconf's --with-xxx=yyy ::
 
-  opts = Variables()
-  opts.Add(PackageVariable('x11',
-                         'use X11 installed here (yes = search some places',
-                         'yes'))
-  ...
-  if env['x11'] == True:
-      dir = ... search X11 in some standard places ...
-      env['x11'] = dir 
-  if env['x11']:
-      ... build with x11 ...
+      opts = Variables()
+      opts.Add(PackageVariable('x11',
+                             'use X11 installed here (yes = search some places',
+                             'yes'))
+      ...
+      if env['x11'] == True:
+          dir = ... search X11 in some standard places ...
+          env['x11'] = dir
+      if env['x11']:
+          ... build with x11 ...
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -50,7 +50,7 @@ Usage example:
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Variables/PackageVariable.py rel_2.3.5:3329:275e75118ad4 2015/06/20 11:18:26 bdbaddog"
+__revision__ = "src/engine/SCons/Variables/PackageVariable.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 __all__ = ['PackageVariable',]
 
@@ -70,10 +70,10 @@ def _converter(val):
 
 
 def _validator(key, val, env, searchfunc):
-    # NB: searchfunc is currenty undocumented and unsupported
+    # NB: searchfunc is currently undocumented and unsupported
     """
     """
-    # todo: write validator, check for path
+    # TODO write validator, check for path
     import os
     if env[key] is True:
         if searchfunc:
@@ -84,14 +84,14 @@ def _validator(key, val, env, searchfunc):
 
 
 def PackageVariable(key, help, default, searchfunc=None):
-    # NB: searchfunc is currenty undocumented and unsupported
+    # NB: searchfunc is currently undocumented and unsupported
     """
     The input parameters describe a 'package list' option, thus they
     are returned with the correct converter and validator appended. The
     result is usable for input to opts.Add() .
 
     A 'package list' option may either be 'all', 'none' or a list of
-    package names (seperated by space).
+    package names (separated by space).
     """
     help = '\n    '.join(
         (help, '( yes | no | /path/to/%s )' % key))
