@@ -8,8 +8,7 @@ Arguments to PathVariable are:
   option-name  = name of this option on the command line (e.g. "prefix")
   option-help  = help string for option
   option-dflt  = default value for this option
-  validator    = [optional] validator for option value.  Predefined
-                 validators are:
+  validator    = [optional] validator for option value.  Predefined validators are:
 
                      PathAccept -- accepts any path setting; no validation
                      PathIsDir  -- path must be an existing directory
@@ -25,7 +24,7 @@ Arguments to PathVariable are:
                  and the env is the env to which the Options have been
                  added.
 
-Usage example:
+Usage example::
 
   Examples:
       prefix=/usr/local
@@ -34,8 +33,8 @@ Usage example:
 
   opts = Variables()
   opts.Add(PathVariable('qtdir',
-                      'where the root of Qt is installed',
-                      qtdir, PathIsDir))
+                        'where the root of Qt is installed',
+                        qtdir, PathIsDir))
   opts.Add(PathVariable('qt_includes',
                       'where the Qt includes are installed',
                       '$qtdir/includes', PathIsDirCreate))
@@ -46,7 +45,7 @@ Usage example:
 """
 
 #
-# Copyright (c) 2001 - 2016 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -68,7 +67,7 @@ Usage example:
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Variables/PathVariable.py rel_2.5.0:3543:937e55cd78f7 2016/04/09 11:29:54 bdbaddog"
+__revision__ = "src/engine/SCons/Variables/PathVariable.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 __all__ = ['PathVariable',]
 
