@@ -5,7 +5,7 @@ customizable variables to an SCons build.
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -26,21 +26,22 @@ customizable variables to an SCons build.
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "src/engine/SCons/Variables/__init__.py rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"
+__revision__ = "src/engine/SCons/Variables/__init__.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 import os.path
 import sys
+from functools import cmp_to_key
 
 import SCons.Environment
 import SCons.Errors
 import SCons.Util
 import SCons.Warnings
 
-from BoolVariable import BoolVariable  # okay
-from EnumVariable import EnumVariable  # okay
-from ListVariable import ListVariable  # naja
-from PackageVariable import PackageVariable # naja
-from PathVariable import PathVariable # okay
+from .BoolVariable import BoolVariable  # okay
+from .EnumVariable import EnumVariable  # okay
+from .ListVariable import ListVariable  # naja
+from .PackageVariable import PackageVariable # naja
+from .PathVariable import PathVariable # okay
 
 
 class Variables(object):
@@ -50,12 +51,17 @@ class Variables(object):
     Holds all the options, updates the environment with the variables,
     and renders the help text.
     """
-    def __init__(self, files=[], args={}, is_global=1):
+    def __init__(self, files=None, args=None, is_global=1):
         """
         files - [optional] List of option configuration files to load
             (backward compatibility) If a single string is passed it is
                                      automatically placed in a file list
         """
+        # initialize arguments
+        if files is None:
+            files = []
+        if args is None:
+            args = {}
         self.options = []
         self.args = args
         if not SCons.Util.is_List(files):
@@ -110,13 +116,13 @@ class Variables(object):
         """
         Add an option.
 
-        key - the name of the variable, or a list or tuple of arguments
-        help - optional help text for the options
-        default - optional default value
-        validator - optional function that is called to validate the option's value
-                    Called with (key, value, environment)
-        converter - optional function that is called to convert the option's value before
-                    putting it in the environment.
+
+        @param key: the name of the variable, or a list or tuple of arguments
+        @param help: optional help text for the options
+        @param default: optional default value
+        @param validator: optional function that is called to validate the option's value
+        @type validator: Called with (key, value, environment)
+        @param converter: optional function that is called to convert the option's value before putting it in the environment.
         """
 
         if SCons.Util.is_List(key) or isinstance(key, tuple):
@@ -136,14 +142,17 @@ class Variables(object):
         Each list element is a tuple/list of arguments to be passed on
         to the underlying method for adding options.
 
-        Example:
-          opt.AddVariables(
+        Example::
+
+            opt.AddVariables(
             ('debug', '', 0),
             ('CC', 'The C compiler'),
             ('VALIDATE', 'An option for testing validation', 'notset',
              validator, None),
             )
+
         """
+
         for o in optlist:
             self._do_add(*o)
 
@@ -170,7 +179,9 @@ class Variables(object):
                     sys.path.insert(0, dir)
                 try:
                     values['__name__'] = filename
-                    exec open(filename, 'rU').read() in {}, values
+                    with open(filename, 'r') as f:
+                        contents = f.read()
+                    exec(contents, {}, values)
                 finally:
                     if dir:
                         del sys.path[0]
@@ -206,7 +217,7 @@ class Variables(object):
                         env[option.key] = option.converter(value)
                     except TypeError:
                         env[option.key] = option.converter(value, env)
-                except ValueError, x:
+                except ValueError as x:
                     raise SCons.Errors.UserError('Error converting option: %s\n%s'%(option.key, x))
 
 
@@ -268,7 +279,7 @@ class Variables(object):
             finally:
                 fh.close()
 
-        except IOError, x:
+        except IOError as x:
             raise SCons.Errors.UserError('Error writing options to file: %s\n%s' % (filename, x))
 
     def GenerateHelpText(self, env, sort=None):
@@ -277,9 +288,13 @@ class Variables(object):
 
         env - an environment that is used to get the current values
               of the options.
+        cmp - Either a function as follows: The specific sort function should take two arguments and return -1, 0 or 1 
+              or a boolean to indicate if it should be sorted.
         """
 
-        if sort:
+        if callable(sort):
+            options = sorted(self.options, key=cmp_to_key(lambda x,y: sort(x.key,y.key)))
+        elif sort is True:
             options = sorted(self.options, key=lambda x: x.key)
         else:
             options = self.options
