@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -27,7 +27,7 @@ This file implements the warnings framework for SCons.
 
 """
 
-__revision__ = "src/engine/SCons/Warnings.py rel_2.3.5:3347:d31d5a4e74b6 2015/07/31 14:36:10 bdbaddog"
+__revision__ = "src/engine/SCons/Warnings.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
 
 import sys
 
@@ -41,10 +41,12 @@ class WarningOnByDefault(Warning):
 
 
 # NOTE:  If you add a new warning class, add it to the man page, too!
-
 class TargetNotBuiltWarning(Warning): # Should go to OnByDefault
     pass
 
+class CacheVersionWarning(WarningOnByDefault):
+    pass
+
 class CacheWriteErrorWarning(Warning):
     pass
 
@@ -72,12 +74,6 @@ class MisleadingKeywordsWarning(WarningOnByDefault):
 class MissingSConscriptWarning(WarningOnByDefault):
     pass
 
-class NoMD5ModuleWarning(WarningOnByDefault):
-    pass
-
-class NoMetaclassSupportWarning(WarningOnByDefault):
-    pass
-
 class NoObjectCountWarning(WarningOnByDefault):
     pass
 
@@ -151,6 +147,9 @@ class DeprecatedSigModuleWarning(MandatoryDeprecatedWarning):
 class DeprecatedBuilderKeywordsWarning(MandatoryDeprecatedWarning):
     pass
 
+class DeprecatedMissingSConscriptWarning(DeprecatedWarning):
+    pass
+
 
 # The below is a list of 2-tuples.  The first element is a class object.
 # The second element is true if that class is enabled, false if it is disabled.
@@ -183,8 +182,8 @@ def warn(clazz, *args):
     global _enabled, _warningAsException, _warningOut
 
     warning = clazz(args)
-    for clazz, flag in _enabled:
-        if isinstance(warning, clazz):
+    for cls, flag in _enabled:
+        if isinstance(warning, cls):
             if flag:
                 if _warningAsException:
                     raise warning
